﻿using System;
using System.Text;
using J2.eFaxDeveloper.Outbound;

namespace J2.eFaxDeveloper.Sample.SampleOutbound
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                // A) Create an instance of OutboundClient to send an outbound fax
                OutboundClient outboundClient = new OutboundClient();

                // B) you have 2 options to configurate the settings of OutboundClient/////////////////////

                // 1) load (previously saved) settings from the configuration file as follow
                //outboundClient.LoadConfiguration();

                // 2) Set the efaxDeveloper settings manualy
                outboundClient.AccountId = "xxxxxx";
                outboundClient.UserName = "xxxxxx";
                outboundClient.Password = "xxxxxx";

                ////////////////////////////////////////////////////////////////////////////////////////

                // C) Create an instance of OutboundRequest, that will encapsulate all the data of the outbound fax 
                OutboundRequest outboundRequest = new OutboundRequest();

                // optionnaly set fax transmission control settings

                // TransmissionID can have a max length 15
                // outboundRequest.TransmissionControl.TransmissionID = "TransID_1234";

                // CustomerID can have a max length 20
                // outboundRequest.TransmissionControl.CustomerID = "CustomerID_1234";

                // Set NoDuplicates (default is Disable)
                // outboundRequest.TransmissionControl.NoDuplicates = NoDuplicates.Enable;

                // Set Resolution (there is no default settings)
                // outboundRequest.TransmissionControl.Resolution = Resolution.Fine;

                // Set Priority (default is Normal)
                // outboundRequest.TransmissionControl.Priority = Priority.High;

                // Set SelfBusy (default is Enable)
                // outboundRequest.TransmissionControl.SelfBusy = SelfBusy.Disable;

                // Set FaxHeader (Default is "the default fax header")
                // outboundRequest.TransmissionControl.FaxHeader = "@DATE1 @TIME3 My Company Name @ROUTETO{26} @RCVRFAX Pg%P/@SPAGES";

                ////////////////////////////////////////////////////////////////////////////////////////
                
                // D) set the fax recipient ///////////////////////////////////////////////////////////////
                outboundRequest.Recipient.RecipientName = "John Doe";
                outboundRequest.Recipient.RecipientCompany = "Company ABC Inc.";
                outboundRequest.Recipient.RecipientFax = "15551234567";

                ////////////////////////////////////////////////////////////////////////////////////////

                // E) add file(s) to fax //////////////////////////////////////////////////////////////////
                FaxFile faxFile1 = new FaxFile();
                faxFile1.FileType = FaxFileType.txt;
                faxFile1.FileContents = Encoding.ASCII.GetBytes("Fax document");
                outboundRequest.Files.Add(faxFile1);

                // example to load add a pdf file
                /*FaxFile faxFile2 = new FaxFile();
                faxFile2.FileType = FaxFileType.pdf;
                faxFile2.FileContents = File.ReadAllBytes("Document.pdf");
                outboundRequest.Files.Add(faxFile2);*/

                /////////////////////////////////////////////////////////////////////////////////////////

                // F) set the disposition settings//////////////////////////////////////////////////////////

                // set the disposition level 
                outboundRequest.DispositionControl.DispositionLevel = DispositionLevel.Both;

                // set the disposition method
                outboundRequest.DispositionControl.DispositionMethod = DispositionMethod.Email;

                // for DispositionMethod.Email set the email address(es) to send the disposition to
                outboundRequest.DispositionControl.DispositionEmails.Add(
                    new DispositionEmail { DispositionAddress = "john.doe@emaildomain.com", DispositionRecipient = "John Doe" });

                // if you choose to receive the disposition via http POST
                // set the disposition method
                /*outboundRequest.DispositionControl.DispositionMethod = DispositionMethod.Post;

                // for DispositionMethod.Post set the DispositionURL where efaxDeveloper send the XML disposition for this fax transmission
                outboundRequest.DispositionControl.DispositionURL = "https://www.mydoman.com/efaxDisposition";
                */

                ///////////////////////////////////////////////////////////////////////////////////////////

                // G) send the oubound fax to efaxDeveloper and get an instance of OutboundResponse back 
                OutboundResponse outboundResponse = outboundClient.SendOutboundRequest(outboundRequest);

                // check if the fax was accepted successfuly
                if (outboundResponse.StatusCode == StatusCode.Success)
                {
                    Console.WriteLine(string.Format("Success: DOCID {0} TransmissionID {1}", outboundResponse.DOCID, outboundResponse.TransmissionID));
                }
                else
                {
                    Console.WriteLine(string.Format("Error: {0} {1}", outboundResponse.ErrorMessage, outboundResponse.ErrorLevel));
                }

                /////////////////////////////////////////////////////////////////////////////////////////////
            }
            catch (Exception ex)
            {
                Console.WriteLine(String.Format("Error: {0}", ex.Message));
            }
        }
    }
}
