﻿using System;
using System.Configuration;
using System.Diagnostics;
using System.IO;
using System.Net;
using System.ServiceModel;
using System.ServiceModel.Activation;
using System.ServiceModel.Web;
using System.Text;
using J2.eFaxDeveloper;

namespace J2.eFaxDeveloper.Sample.SampleInbound
{
    [AspNetCompatibilityRequirements(RequirementsMode = AspNetCompatibilityRequirementsMode.Allowed)]
    [ServiceContract]
    public class InboundFaxService
    {
        /// <summary>
        /// This method will receive any data via a http POST to ~/InboundFaxService.svc/receive
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        [OperationContract]
        [WebInvoke(Method = "POST", UriTemplate = "receive")]
        public Stream Receive(Stream data)
        {
            try
            {
                // the data received will be URL encode and have an "xml" parameter
                // that will contains your fax disposition data
                // Use XmlUtils to extract the xml

                XmlUtils xmlUtils = new XmlUtils();

                string xml = xmlUtils.ExtractXMLFromURLEncodedData(data);

                string path = Path.Combine(ConfigurationManager.AppSettings["InboundFax"],
                                           string.Format("{0}.xml", Guid.NewGuid()));

                // save the xml to disk
                using (StreamWriter sw = new StreamWriter(path))
                {
                    sw.Write(xml);
                }

                // You could also use J2.eFaxDeveloper.Inbound.InboundClient to parse the xml
                // and check the username and password and/or any additional action that your application requires
                /*
                InboundClient inboundClient = new InboundClient();

                InboundPostRequest inboundPostRequest = inboundClient.DeserializeInboundPostRequest(xml);
                */

                if (WebOperationContext.Current != null)
                {
                    WebOperationContext.Current.OutgoingResponse.StatusCode = HttpStatusCode.OK;
                    WebOperationContext.Current.OutgoingResponse.ContentType = "text/html";
                }

                // return "Post Successful" to efaxDeveloper to Acknowledge the successful reception of the fax
                return new MemoryStream(Encoding.UTF8.GetBytes("<html><body>Post Successful</body></html>"));
            }
            catch (Exception ex)
            {
                Trace.TraceError(ex.Message);
            }

            return null;
        }
    }
}
