﻿using System;
using System.Configuration;
using System.Diagnostics;
using System.IO;
using System.Net;
using System.ServiceModel;
using System.ServiceModel.Activation;
using System.ServiceModel.Web;
using System.Text;
using System.Web;

namespace J2.eFaxDeveloper.Sample.SampleOutbound
{
    [AspNetCompatibilityRequirements(RequirementsMode = AspNetCompatibilityRequirementsMode.Allowed)]
    [ServiceContract]
    public class OutboundDispositionService
    {
        /// <summary>
        /// This method will receive any data via a http POST to ~/OutboundDispositionService.svc/receive
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        [OperationContract]
        [WebInvoke(Method = "POST", UriTemplate = "receive")]
        public Stream Receive(Stream data)
        {
            try
            {
                // the data received will be URL encode and have an "xml" parameter
                // that will contains your fax disposition data
                // Use XmlUtils to extract the xml
                XmlUtils xmlUtils = new XmlUtils();

                string xml = xmlUtils.ExtractXMLFromURLEncodedData(data);

                // get the location of where the xml will be save, from the configuration file
                string path = Path.Combine(ConfigurationManager.AppSettings["OutboundDisposition"],
                                           string.Format("{0}.xml", Guid.NewGuid()));

                // save the xml to disk
                using (StreamWriter sw = new StreamWriter(path))
                {
                    sw.Write(xml);
                }

                // You could also use J2.eFaxDeveloper.Outbound.OutboundClient to parse the xml
                /*
                OutboundClient outboundClient = new OutboundClient();
                         
                OutboundDisposition outboundDisposition = outboundClient.DeserializeOutboundDisposition(xml);
                */

                if (WebOperationContext.Current != null)
                {
                    WebOperationContext.Current.OutgoingResponse.StatusCode = HttpStatusCode.OK;
                    WebOperationContext.Current.OutgoingResponse.ContentType = "text/html";
                }

                // return "Post Successful" to efaxDeveloper to Acknowledge the successful reception of the outbound disposition
                return new MemoryStream(Encoding.UTF8.GetBytes("<html><body>Post Successful</body></html>"));
            }
            catch (Exception ex)
            {
                Trace.TraceError(ex.Message);
            }

            return null;
        }
    }
}
